@@ -8,6 +8,7 @@ import (
 	"github.com/mzz2017/softwind/pkg/fastrand"
 	"io"
 	"net"
+	"sync"
 	"time"
 )
 
@@ -22,6 +23,8 @@ type TLSObfs struct {
 	remain        int
 	firstRequest  bool
 	firstResponse bool
+	rMu           sync.Mutex
+	wMu           sync.Mutex
 }
 
 func (to *TLSObfs) read(b []byte, discardN int) (int, error) {
@@ -50,6 +53,8 @@ func (to *TLSObfs) read(b []byte, discardN int) (int, error) {
 }
 
 func (to *TLSObfs) Read(b []byte) (int, error) {
+	to.rMu.Lock()
+	defer to.rMu.Unlock()
 	if to.remain > 0 {
 		length := to.remain
 		if length > len(b) {
@@ -73,6 +78,8 @@ func (to *TLSObfs) Read(b []byte) (int, error) {
 	return to.read(b, 3)
 }
 func (to *TLSObfs) Write(b []byte) (int, error) {
+	to.wMu.Lock()
+	defer to.wMu.Unlock()
 	length := len(b)
 	for i := 0; i < length; i += chunkSize {
 		end := i + chunkSize
